==================================
Stacked Widget (``stackedwidget``)
==================================

.. automodule:: orangecanvas.gui.stackedwidget

.. autoclass:: orangecanvas.gui.stackedwidget.AnimatedStackedWidget
   :members:
   :member-order: bysource
   :show-inheritance:


   .. autoattribute:: currentChanged(int)

      Current widget has changed

   .. autoattribute:: transitionStarted()

      Transition animation has started

   .. autoattribute:: transitionFinished()

      Transition animation has finished


.. autoclass:: orangecanvas.gui.stackedwidget.StackLayout
   :members:
   :member-order: bysource
   :show-inheritance:
